@@ -1,7 +1,7 @@
 package GIS::Distance::Polar;
 use 5.008001;
 use strictures 2;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use Math::Trig qw( deg2rad pi );
 use GIS::Distance::Constants qw( :all );
@@ -41,6 +41,9 @@ PLEASE share your results with the author.  I've tested the results of this
 formula versus L<GIS::Distance::Vincenty> and it appears that this formula
 is broken (or the implementation is) as you can see in C<t/polar.t>.
 
+A faster (XS) version of this formula is available as
+L<GIS::Distance::Fast::Polar>.
+
 Normally this module is not used directly.  Instead L<GIS::Distance>
 is used which in turn interfaces with the various formula modules.
 
